@@ -31,9 +31,9 @@ class BugzillaManager;
 class ReportAssistantPage: public QWidget
 {
     Q_OBJECT
-    
+
 public:
-    ReportAssistantPage(ReportAssistantDialog * parent);
+    explicit ReportAssistantPage(ReportAssistantDialog * parent);
 
     /** Load the widget data if empty **/
     virtual void aboutToShow() {}
@@ -41,10 +41,10 @@ public:
     virtual void aboutToHide() {}
     /** Tells the KAssistantDialog to enable the Next button **/
     virtual bool isComplete();
-    
+
     /** Last time checks to see if you can turn the page **/
     virtual bool showNextPage();
-    
+
     ReportInterface *reportInterface() const;
     BugzillaManager *bugzillaManager() const;
     ReportAssistantDialog * assistant() const;
